/**
* @file   : adc.h
* @brief  : adc  ..    
* @author : carroty / carroty.com : jung sang hoon / company
* @date   : 2012.04.09
* @remarks
* -  1
* -  2
* @par [̷]
* - 2012.xx.xx /  / v1.0 /  
* - 2012.xx.xx /  / v1.1 /  
*/

#ifndef __ADC_H__
#define __ADC_H__

// ADC channel defines
#define ADC_CH_0                 0x00
#define ADC_CH_1                 0x01
#define ADC_CH_2                 0x02
#define ADC_CH_3                 0x03
#define ADC_CH_4                 0x04
#define ADC_CH_5                 0x05
#define ADC_CH_6                 0x06
#define ADC_CH_7                 0x07
#define ADC_CH_122V             0x1E    ///< 1.22V voltage reference
#define ADC_CH_AGND             0x1F    ///< AGND


// ADC voltage reference select
#define ADC_REFERENCE_AREF      0x00    ///< 0x00 -> AREF pin, internal VREF turned off
#define ADC_REFERENCE_AVCC      0x01    ///< 0x01 -> AVCC pin, internal VREF turned off
#define ADC_REFERENCE_RSVD      0x02    ///< 0x02 -> Reserved
#define ADC_REFERENCE_256V      0x03    ///< 0x03 -> Internal 2.56V VREF

// ADC clock prescaler select
#define ADC_PRESCALER_DIV002    0x00  // 0x01, 0x00 -> CPU clk/2
#define ADC_PRESCALER_DIV004    0x02  // CPU clk/4
#define ADC_PRESCALER_DIV008    0x03  // CPU clk/8
#define ADC_PRESCALER_DIV016    0x04  // CPU clk/16
#define ADC_PRESCALER_DIV032    0x05  // CPU clk/32
#define ADC_PRESCALER_DIV064    0x06  // CPU clk/64
#define ADC_PRESCALER_DIV128    0x07  // CPU clk/128

// these channels supported only in ATmega128 differential with gain
#define ADC_CH_0_0_DIFF10X      0x08
#define ADC_CH_1_0_DIFF10X      0x09
#define ADC_CH_0_0_DIFF200X     0x0A
#define ADC_CH_1_0_DIFF200X     0x0B
#define ADC_CH_2_2_DIFF10X      0x0C
#define ADC_CH_3_2_DIFF10X      0x0D
#define ADC_CH_2_2_DIFF200X     0x0E
#define ADC_CH_3_2_DIFF200X     0x0F
// differential
#define ADC_CH_0_1_DIFF1X       0x10
#define ADC_CH_1_1_DIFF1X       0x11
#define ADC_CH_2_1_DIFF1X       0x12
#define ADC_CH_3_1_DIFF1X       0x13
#define ADC_CH_4_1_DIFF1X       0x14
#define ADC_CH_5_1_DIFF1X       0x15
#define ADC_CH_6_1_DIFF1X       0x16
#define ADC_CH_7_1_DIFF1X       0x17
 
#define ADC_CH_0_2_DIFF1X       0x18
#define ADC_CH_1_2_DIFF1X       0x19
#define ADC_CH_2_2_DIFF1X       0x1A
#define ADC_CH_3_2_DIFF1X       0x1B
#define ADC_CH_4_2_DIFF1X       0x1C
#define ADC_CH_5_2_DIFF1X       0x1D

// function prototypes
void adcInit(unsigned char cannel, unsigned char mode);
void adcSetPrescaler(unsigned char prescale);
void adcSetReferance(unsigned char referance);
void adcSetChannel(unsigned char channel);
void adcStartConvert(void);
void adcStopConvert(void);
void adcIsComplete(void);
void adcConvertBit(unsigned char bit); // 8 or 10 bit
void adc2GradeValue(unsigned int value);

void adc_init(unsigned char cannel);
void adc_start(void);

//intterrupt signal(SIG_ADC);
#endif
