#include <avr/io.h>
#include <avr/interrupt.h>

#include "global.h"
#include "delay.h"

#define BAUD_57600	57600
#define CR 0x0D
#define LF 0x0A

void uart0_init(unsigned int baud_rate) {                                        
  baud_rate = ((F_CPU+(baud_rate*8L))/(baud_rate*16L)-1);  
  UBRR0H=(unsigned char) (baud_rate >> 8);             
  UBRR0L=(unsigned char) (baud_rate & 0xFF);           

  // enable tx/rx and no interrupt on tx/rx 
  sbi(UCSR0B,RXEN0);
  sbi(UCSR0B,TXEN0);        

  cbi(UCSR0C,UMSEL1);   // asynchronous
  cbi(UCSR0C,USBS1);    // 1 Stop bit
								
  cbi(UCSR0C,UPM01);    // NO Parity
  cbi(UCSR0C,UPM00);

  cbi(UCSR0B,UCSZ02);	// 8bit data
  sbi(UCSR0C,UCSZ01);
  sbi(UCSR0C,UCSZ00);		
}

void tx_data(unsigned char data) {
  while(!(UCSR0A & 0x20)); // UDRE0  ȵǿ! 
  UDR0= data;
}

void tx_char(unsigned char ch) {
  tx_data(ch);
}


char rx_data(void) {
  while(!(UCSR0A & 0x80));
  return UDR0;
}


void tx_string(char *string) {
  while(*string !='\0') {        // null Ʈ ö  
    if(*string =='\n') { 
	  tx_data(CR);               // CR+LF 
      tx_data(LF);
    }
	else { tx_data(*string); }
	string++;
  }
}

