#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdio.h>

#include "global.h"
#include "delay.h"
#include "uart.h"
#include "key.h"
#include "led.h"
#include "ascii.h"

void init_port();
void tx_menu();
void set_led_status(unsigned char position);
unsigned char get_led_status(unsigned char position);
char * convert_int_string(unsigned char value);
void led_status_output();

unsigned char led_array[4]= {OFF, OFF, OFF, OFF};
unsigned char key_from_computer=0;
unsigned char key_from_board=0;

#define LED_PORT PORTB
#define KEY_PORT PORTD

#define LED_PORT_DIRECTION DDRB
#define KEY_PORT_DIRECTION DDRD

void init_port() {
  LED_PORT=0x0F;
  KEY_PORT=0xC3;
  LED_PORT_DIRECTION=LED_FULL_OFF;
}

void tx_menu() {
   tx_string("\n\n");
   tx_string("------------------\n");
   tx_string("LsssED CONTROLLER \n");
   tx_string("------------------\n");
   tx_string("[1] LED1");tx_string(convert_int_string(get_led_status(1)));tx_string("\n");
   tx_string("[2] LED1");tx_string(convert_int_string(get_led_status(2)));tx_string("\n");
   tx_string("[3] LED1");tx_string(convert_int_string(get_led_status(3)));tx_string("\n");
   tx_string("[4] LED1");tx_string(convert_int_string(get_led_status(4)));tx_string("\n");
   tx_string("------------------\n");
   tx_string("input key....");
}

void set_led_status(unsigned char position) {
  if(get_led_status(position)==ON) {  led_array[position-1]= OFF;}
  else  if(get_led_status(position)==OFF) {  led_array[position-1]= ON;}
}

unsigned char get_led_status(unsigned char position) {
  return led_array[position-1];
}

char * convert_int_string(unsigned char value) {
  if(value==1) return 'ON';
  else return 'OFF';
}

ISR(USART0_RX_vect) {
  key_from_computer=UDR0;
  switch(key_from_computer) {
    case ASCII_1:
      set_led_status(1);
      led_status_output();
      tx_menu();
      tx_char(ASCII_1);
      break;
    case ASCII_2:
      set_led_status(2);
      led_status_output();
      tx_menu();
      tx_char(ASCII_2);
      break;
    case ASCII_3:
      set_led_status(3);
      led_status_output();
      tx_menu();
      tx_char(ASCII_3);
      break;
    case ASCII_4:
      set_led_status(4);
      led_status_output();
      tx_menu();
      tx_char(ASCII_4);
      break;
    default:
      tx_string('\ninput correct computer key..');
      break;
  }
}
int main(void) {
   init_port();
   uart0_init(BAUD_57600);
   sei();
   tx_menu();
 
  while(true) {
    key_from_board=key_input();

    switch(key_from_board) {
       case KEY_1 :
       set_led_status(1);
       led_status_output();
       tx_menu();
       tx_char(ASCII_1);
       break;
       case KEY_2:
       set_led_status(2);
       led_status_output();
       tx_menu();
       tx_char(ASCII_2);
       break;
       case KEY_3 :
       set_led_status(3);
       led_status_output();
       tx_menu();
       tx_char(ASCII_3);
       break;
       case KEY_4 :
       set_led_status(4);
       led_status_output();
       tx_menu();
       tx_char(ASCII_4);
       break;
    }
  }
  return 0; 
}


void led_status_output() {
  unsigned char i=0;
  for(i=0; i<4; i++) {
  if(led_array[i]==1) { cbi(LED_PORT, i); }
  else { sbi(LED_PORT, i); }
  }
}

